# ПРИМЕР ЧТЕНИЯ ВСЕХ ЗНАЧЕНИЙ ПРИ ИХ ИЗМЕНЕНИИ:

#   Подключаем библиотеку для работы с датчиком температуры и влажности I2C-flash (Sensor Humidity and Temperature).
from pyiArduinoI2Csht import *
from time import sleep

# Объявляем объект sht для работы с функциями и методами библиотеки pyiArduinoI2Csht.
# Если при объявлении объекта указать адрес, например, sht(0xBB), то пример будет
# работать с тем модулем, адрес которого был указан.
sht = pyiArduinoI2Csht()

# Указываем фиксировать изменение температуры окружающей среды более чем на 0.1°С.
sht.setTemChange(0.1)

# Указываем фиксировать изменение влажности воздуха более чем на 1%.
sht.setHumChange(1.0)

while True:

    # Если температура окружающей среды изменилась более чем
    # на значение указанное в функции setTemChange(), то ...
    if sht.getTemChanged():

        # Выводим текущую температуру окружающей среды, от -40 до +125°С.
        print("Температура = %.1f" %
               sht.getTem(),
              "°С.")

    # Если влажность воздуха изменилась более чем на значение указанное в функции setHumChange(), то ...
    if sht.getHumChanged():

        # Выводим текущую влажность воздуха, от 0 до 100%.
        print("Влажность = %.1f" %
               sht.getHum(),
              "%.")
    sleep(0.1)
